/* ratoli.c */

#include <graphics.h>
#include <dos.h>
#include <stdio.h>
#include <stdlib.h>
#include "libgraf.h"
#include "ratoli.h"

#define  RESET_RATOLI   0  /* Reset del ratol i retorna estat */
#define  MOSTRA_RATOLI  1  /* Mostra el cursor del ratol */
#define  AMAGA_RATOLI   2  /* Treu el cursor del ratol */
#define  ESTAT_RATOLI   3  /* Retorna posici ratol i estat dels botons */
#define  POSA_RATOLI    4  /* Situa cursor del ratol a la posici indicada */
#define  BOTO_PREMUT    5  /* N. de vegades que s'ha premut un bot */
#define  BOTO_DESPREMUT 6  /* N. de vegades que s'ha despremut */
#define  LIMIT_HORIT    7  /* Estableix limits horitzontals del cursor */
#define  LIMIT_VERT     8  /* Estableix limits verticals del cursor */

static struct REGPACK reg;

static int  RatoliInstallat ();
static void PosaRatoli (int x, int y);
static void LimitsRatoli (int xmin, int ymin, int xmax, int ymax);
static void ObteCoordBoto (int *x, int *y, int *boto);
static void ObteCoord (int *x, int *y);
static int  ObteBoto ();


/**************************************************************************
   Si el ratol est instal.lat, el mostra a la posici indicada i defineix
   els limits horitzontals i verticals (viewport),
   sin est instal.lat, acaba.
 **************************************************************************/
void IniLocatorRatoli (int x, int y, Viewport v)
{
   if (RatoliInstallat ())
   {
	 LimitsRatoli (v.vmin.x, v.vmin.y, v.vmax.x, v.vmax.y);
     PosaRatoli (x, y);
   }
   else
   {
     printf("No s'ha detectat driver per ratol.");
     exit (1);
   }
}


/*************************************************************
   Retorna les coordenades del punt on s'ha apretat un bot.
	 boto = 1 : S'ha apretat el bot esquerre.
	 boto = 2 : S'ha apretat el bot dret.
 *************************************************************/
void RequestLocatorRatoli (int *x, int *y, int *boto)
{
  int boto_apretat;

  MostraRatoli();

/* Per provar-ho
   ObteCoord (x, y); printf("\n %d %d", *x, *y); exit (1);
   Escriu (239, 479) */

  ObteCoordBoto (x, y, boto);
  while ( ! *boto )        ObteCoordBoto (x, y, boto);
  boto_apretat = *boto;
  while ( boto_apretat )   ObteCoordBoto (x, y, &boto_apretat);
  AmagaRatoli();
}


/*************************************************************
   Retorna les coordenades del punt on est situat el ratol
   i ens indica si s'ha apretat un bot i quin bot.
	 boto = 0 : No s'ha apretat cap bot.
	 boto = 1 : S'ha apretat el bot esquerre.
	 boto = 2 : S'ha apretat el bot dret.
 *************************************************************/
void SampleLocatorRatoli (int *x, int *y, int *boto)
{
  int boto_apretat;

  ObteCoordBoto (x, y, boto);
  if ( *boto ) {
	boto_apretat = *boto;
	while ( boto_apretat )   ObteCoordBoto (x, y, &boto_apretat);
  }
}


void AmagaRatoli (void)
{
  reg.r_ax= AMAGA_RATOLI;
  intr (51, &reg);
}


void MostraRatoli (void)
{
  reg.r_ax= MOSTRA_RATOLI;
  intr (51, &reg);
}


static int RatoliInstallat ()
{
  reg.r_ax= RESET_RATOLI;
  intr (51, &reg);
  return (reg.r_ax);
}


static void PosaRatoli (int x, int y)
{
  reg.r_ax= POSA_RATOLI;
  reg.r_cx= x;
  reg.r_dx= y;
  intr (51, &reg);
}


static void LimitsRatoli (int xmin, int ymin, int xmax, int ymax)
{
  reg.r_ax= LIMIT_HORIT;
  reg.r_cx= xmin;
  reg.r_dx= xmax;
  intr (51, &reg);
  reg.r_ax= LIMIT_VERT;
  reg.r_cx= ymin;
  reg.r_dx= ymax;
  intr (51, &reg);
}


static void ObteCoordBoto (int *x, int *y, int *boto)
/* boto = 0 : No s'ha premut cap bot
   boto = 1 : S'ha premut el bot esquerre
   boto = 2 : S'ha premut el bot dret
   boto = 4 : S'ha premut el bot del mig     */
{
  reg.r_ax= ESTAT_RATOLI;
  intr (51, &reg);
  *boto = reg.r_bx;
  *x= reg.r_cx; *y= reg.r_dx;
}


static void ObteCoord (int *x, int *y)
{
  reg.r_ax= ESTAT_RATOLI;
  intr (51, &reg);
  *x= reg.r_cx; *y= reg.r_dx;
}


static int ObteBoto ()
/* Retorna el bot premut:
	  0 : No s'ha premut cap bot
	  1 : S'ha premut el bot esquerre
	  2 : S'ha premut el bot dret
	  4 : S'ha premut el bot del mig     */
{
  reg.r_ax= ESTAT_RATOLI;
  intr (51, &reg);
  return(reg.r_bx);
}
