#ifndef SetFileInformation
#define SetFileInformation _SetFileInformation
#define ScanFileInformation _ScanFileInformation
#endif

/*****************************************************************************
 *
 * Program Name:  Novell 'C' Library
 *
 * Filename:	  nit.h
 *
 * Date Created:  October 9, 1987
 *
 * Version:		  1.0
 *
 * Programmers:	  Tom L. Bogart
 *
 * Files used:
 *
 * Date Modified:
 *
 * Modifications:
 *
 * Comments:
 *
 * COPYRIGHT (c) 1986 by Novell, Inc.  All Rights Reserved.
 *
 ****************************************************************************/

#ifndef PROLOG
#include <prolog.h>
#endif
  /**************************/
  /* Definimos WORD y BYTE  */
  /**************************/

#define WORD  unsigned short
#define BYTE  unsigned char


/****************************************************************************/

/* ***************************** Error Messages *************************** */
#define BINERY_FAILURE					((BYTE)0xFF)
#define SERVER_IN_USE					((BYTE)0x01)
#define SERVER_NOT_IN_USE				((BYTE)0x00)
#define SEMAPHORE_OVERFLOW				((BYTE)0x01)
#define NO_RECORD_FOUND					((BYTE)0xFF)
#define TTS_NOT_AVAILABLE				((BYTE)0x00)
#define TTS_AVAILABLE					((BYTE)0x01)
#define TTS_DISABLED					((BYTE)0xFD)
#define IMPLICIT_TRANSACTION_ACTIVE		((BYTE)0xFE)
#define EXPLICIT_TRANSACITON_ACTIVE		((BYTE)0xFF)
#define SUCCESSFUL						((BYTE)0x00)
#define EXPLICIT_TRANSACTION_NOT_ACTIVE	((BYTE)0xFF)
#define TRANSACTION_ENDS_RECORDS_LOCKED	((BYTE)0xFE)
#define TRANSACTION_NOT_YET_WRITTEN		((BYTE)0xFF)

/**** Bindery security definitions ****/
#define BS_ANY_READ			((BYTE)0x00) /* Readable by anyone */
#define BS_LOGGED_READ		((BYTE)0x01) /* Must be logged in to read */
#define BS_OBJECT_READ		((BYTE)0x02) /* Readable by same object or super */
#define BS_SUPER_READ		((BYTE)0x03) /* Readable by supervisor only */
#define BS_BINDERY_READ		((BYTE)0x04) /* Readable only by the bindery */
#define BS_ANY_WRITE		((BYTE)0x00) /* Writeable by anyone */
#define BS_LOGGED_WRITE		((BYTE)0x10) /* Must be logged in to write */
#define BS_OBJECT_WRITE		((BYTE)0x20) /* Writeable by same object or super */
#define BS_SUPER_WRITE		((BYTE)0x30) /* Writeable only by the supervisor */
#define BS_BINDERY_WRITE	((BYTE)0x40) /* Writeable by the bindery only */

/* Bindery object type definitions */
#define OT_WILD				(-1)	/* Matches any type					*/
#define OT_UNKNOWN			0		/* Unknown object type				*/
#define OT_USER				1		/* The object is a "user"			*/
#define OT_USER_GROUP		2		/* The object is a group of users	*/
#define OT_PRINT_QUEUE		3		/* The object services print queues	*/
#define OT_FILE_SERVER		4		/* The object serves files			*/
#define OT_JOB_SERVER		5
#define OT_GATEWAY			6
#define OT_PRINT_SERVER		7
#define OT_ARCHIVE_QUEUE	8
#define OT_ARCHIVE_SERVER	9		/* The object services backup jobs	*/
#define OT_JOB_QUEUE		10
#define OT_ADMINISTRATION	11

#define OT_NAS_SNA_GATEWAY	33
#define OT_REMOTE_BRIDGE_SERVER	38
#define OT_TCPIP_GATEWAY		39

/* Drive flags */
#define DRIVE_LOCAL			((BYTE)'\x80')
#define DRIVE_PERMANENT		((BYTE)'\x01')
#define DRIVE_TEMPORARY		((BYTE)'\x02')
#define DRIVE_NETWORK		((BYTE)'\x03')

/* File Attributes */
#ifndef FA_READ_ONLY
#define FA_NORMAL			((BYTE)0x00)
#define FA_READ_ONLY		((BYTE)0x01)
#define FA_HIDDEN			((BYTE)0x02)
#define FA_SYSTEM			((BYTE)0x04)
#define FA_EXECUTE_ONLY		((BYTE)0x08)
#define FA_DIRECTORY		((BYTE)0x10)
#define FA_NEEDS_ARCHIVED	((BYTE)0x20)
#define FA_SHAREABLE		((BYTE)0x80)
/* Extended file attributes */
#define FA_TRANSACTIONAL	((BYTE)0x10)
#define FA_INDEXED			((BYTE)0x20)
#define FA_READ_AUDIT		((BYTE)0x40)
#define FA_WRITE_AUDIT		((BYTE)0x80)
#endif

/* Trustee Access Rights in a network directory */
#define TA_NONE				((BYTE)0x00)
#define TA_READ				((BYTE)0x01)
#define TA_WRITE			((BYTE)0x02)
#define TA_OPEN				((BYTE)0x04)
#define TA_CREATE			((BYTE)0x08)
#define TA_DELETE			((BYTE)0x10)
#define TA_OWNERSHIP		((BYTE)0x20)
#define TA_SEARCH			((BYTE)0x40)
#define TA_MODIFY			((BYTE)0x80)
#define TA_ALL				((BYTE)0xFF)

/* Attributes of objects and properties in the bindery */
#define BF_STATIC		((BYTE)0x00)
#define BF_DYNAMIC		((BYTE)0x01)
#define BF_ITEM			((BYTE)0x00)
#define BF_SET			((BYTE)0x02)

/* Drive Constants */
#define NO_BASE_DRIVE	((BYTE)'\xff')
#define TEMPORARY_DRIVE	((BYTE)0)
#define PERMANENT_DRIVE	((BYTE)1)
#define TEMP_DRIVE		((BYTE)26)
#define TEMP_DRIVE1		((BYTE)27)
#define TEMP_DRIVE2		((BYTE)28)
#define TEMP_DRIVE3		((BYTE)29)

#define MAXSERVERS		8

/****************************************************************************/

#ifdef BIG_MEMORY
#ifdef PROTOTYPE
extern int    AddBinderyObjectToSet(char *, int, char *, char *, int);
extern int    AddTrusteeToDirectory(BYTE, char *, long, BYTE);
extern int    AllocPermanentDirectoryHandle(BYTE, char *, char, BYTE *, BYTE *);
extern int    AllocTemporaryDirectoryHandle(BYTE, char *, char, BYTE *,	BYTE *);
extern int    AppendToCaptureFile(WORD, char *);
extern int    AttachToFileServer(char *, WORD *);
extern int    BroadcastToConsole(char *);
extern int    CancelCaptureFile(void);
extern int    CancelLPTCapture(void);
extern int    ChangeBinderyObjectPassword(char *, int, char *, char *);
extern int    ChangeBinderyObjectSecurity(char *, int, BYTE);
extern int    ChangePropertySecurity(char *, int, char *, BYTE);
extern int    CheckConsolePrivileges(void);
extern int    CheckNetWareVersion(WORD, WORD, WORD, WORD, WORD);
extern int    CheckPipeStatus( WORD *, BYTE *, WORD );
extern int    ClearConnectionNumber(WORD);
extern int    ClearFile(char *);
extern void   ClearFileSet(void);
extern int    ClearLogicalRecord(char *);
extern void   ClearLogicalRecordSet(void);
extern int    ClearPhysicalRecord(int, long, long);
extern void   ClearPhysicalRecordSet(void);
extern int    CloseBindery(void);
extern int    CloseMessagePipe(WORD *, BYTE *, WORD);
extern int    CloseSemaphore(long);
extern int    ConvertNameToFullPath(char *, char *);
extern int    ConvertNameToVolumePath(char *, char *);
extern int    CreateBinderyObject(char *, int, BYTE, BYTE);
extern int    CreateDirectory(BYTE, char *, BYTE);
extern int    CreateProperty(char *, int, char *, BYTE, BYTE);
extern int    DeallocateDirectoryHandle(BYTE);
extern int    DeleteBinderyObject(char *, int);
extern int    DeleteBinderyObjectFromSet(char *, int, char *, char *, int);
extern int    DeleteDirectory(BYTE, char *);
extern int    DeletePrintQueueEntries(int, int, BYTE *);
extern int    DeletePrintQueueEntry(int, BYTE);
extern int    DeleteProperty(char *, int, char *);
extern int    DeleteTrusteeFromDirectory(BYTE, char *, long);
extern void   DetachFromFileServer(WORD);
extern int    DisableBroadcasts(void);
extern int    DisableFileServerLogin(void);
extern int    DisablePrinterDefaults(void);
extern int    DisableTransactionTracking(void);
extern int    DownFileServer(int);
extern int    EnableBroadcasts(void);
extern int    EnableFileServerLogin(void);
extern int    EnablePrinterDefaults(void);
extern int    EnableTransactionTracking(void);
extern void   EndLPTCapture(void);
extern void   EndOfJob(void);
extern int    EnterLoginArea(char *, int);
extern int    EraseFiles(BYTE, char *, BYTE);
extern int    ExamineSemaphore(long, int *, WORD *);
extern int    FileServerFileCopy(int, int, long, long, long, long *);
extern int   _FileServiceRequest(BYTE, BYTE *, WORD, BYTE *, WORD);
extern int    GetBinderyAccessLevel(BYTE *, long *);
extern int    GetBinderyObjectID(char *, int, long *);
extern int    GetBinderyObjectName(long, char *, int *);
extern int    GetBroadcastMessage(char *);
extern BYTE   GetBroadcastMode(void);
extern int    GetCaptureInfo(BYTE *, BYTE *, WORD *, WORD *, WORD *, WORD *, BYTE *, WORD *, long *);
extern int    GetConnectionHandle(char *, WORD *);
extern int    GetConnectionInformation(WORD, char *, int *, long *, BYTE *);
extern WORD   GetConnectionNumber(void);
extern WORD   GetDefaultConnectionID(void);
extern BYTE   GetDefaultLocalPrinter();
extern int    GetDirectoryPath(BYTE, char *);
extern int    GetDiskUtilization(long, char, WORD *, WORD *, WORD *);
extern BYTE   GetDriveInformation(BYTE, WORD *, BYTE *);
extern int    GetEffectiveDirectoryRights(BYTE, char *, BYTE *);
extern WORD  _GetEnvironmentSeg(void);
extern int    GetEnvironmentVariable(char *, char *);
extern int    GetExtendedFileAttributes(char *, BYTE *);
extern void   GetFileServerDateAndTime(BYTE *);
extern int    GetFileServerDescriptionStrings(char *, char *, char *, char *);
extern int    GetFileServerExtendedInfo(BYTE *, BYTE *, BYTE *, BYTE *, BYTE *, BYTE *, BYTE *);
extern int    GetFileServerInformation(char *, BYTE *, BYTE *, WORD *, WORD *, WORD *, BYTE *, BYTE *, BYTE *, WORD *);
extern int    GetFileServerLoginStatus(int *);
extern void   GetFileServerName(WORD, char *);
extern int    GetFullPath(char, char *);
extern int    GetInternetAddress(WORD, char *, char *);
extern WORD   GetLockMode(void);
extern int    GetNetworkSerialNumber(long *, int *);
extern int    GetNumberOfLocalDrives(void);
extern int    GetObjectConnectionNumbers(char *, int, WORD *, WORD *, WORD);
extern int    GetPersonalMessage(char *, WORD *);
extern int    GetPipeStatus(BYTE *, BYTE *, BYTE);
extern WORD   GetPreferredConnectionID(void);
extern WORD   GetPrimaryConnectionID(void);
extern int    GetPrinterDefaults(int *, int *, int *, int *, int *, int *, char *, int *, int *, int *);
extern int    GetPrinterStatus(int, BYTE *, BYTE *, int *, int *);
extern int    GetPrintQueueEntry(int, BYTE *, char *, BYTE *, int *, int *, int *, char *, WORD *, long *, BYTE *);
extern void   GetSearchDriveVector(BYTE *);
extern void   GetShellRevision(BYTE *, BYTE *);
extern void   GetStationAddress(BYTE *);
extern int    GetVolumeInfoWithHandle(BYTE, char *, WORD *, WORD *, WORD *, WORD *, WORD *, WORD *);
extern int    GetVolumeInfoWithNumber(BYTE, char *, WORD *, WORD *, WORD *, WORD *, WORD *, WORD *);
extern int    GetVolumeName(int, char *);
extern int    GetVolumeNumber(char *, int *);
extern void  _GetWorkstationEnvironment(char *);
extern void   GetWorkstationEnvironment(char *, char *, char *, char *);
extern int    IntSwap(int);
extern int    IsBinderyObjectInSet(char *, int, char *, char *, int);
extern int    IsConnectionIDInUse(int);
extern int    LockFileSet(WORD);
extern int    LockLogicalRecordSet(WORD);
extern int    LockPhysicalRecordSet(BYTE, WORD);
extern int    LogFile(char *, BYTE, WORD);
extern int    LoginToFileServer(char *, int, char *);
extern int    LoginUser(char *, char *);
extern int    LogLogicalRecord(char *, BYTE, WORD);
extern int    LogNetworkMessage(char *);
extern void   Logout(void);
extern void   LogoutFromFileServer(WORD);
extern int    LogPhysicalRecord(int, long, long, BYTE, WORD);
extern long   LongSwap(long);
extern int    LPTCaptureActive(WORD *);
extern int   _MemberBinderyCall(int, char *, int, char *, char *, int);
extern void   ModifyLSTDevice(BYTE, BYTE);
extern int    ModifyMaximumRightsMask(BYTE, char *, BYTE, BYTE);
extern int    OpenBindery(void);
extern int    OpenMessagePipe(WORD *, BYTE *, WORD);
extern int    OpenSemaphore(char *, int, long *, WORD *);
extern int    ParsePath(char *, char *, char *, char *);
extern int    PurgeAllErasedFiles(void);
extern int    PurgeErasedFiles(void);
extern int    PutEnvironmentVariable(char *, char *);
extern int    QueueCaptureFile(void);
extern int    QueueExistingFile(BYTE, char *);
extern BYTE *_ReadEnvironment(void);
extern int    ReadPropertyValue(char *, int, char *, int, BYTE *, BYTE *, BYTE *);
extern int    ReleaseFile(char *);
extern void   ReleaseFileSet(void);
extern int    ReleaseLogicalRecord(char *);
extern void   ReleaseLogicalRecordSet(void);
extern int    ReleasePhysicalRecord(int, long, long);
extern void   ReleasePhysicalRecordSet(void);
extern int    RenameBinderyObject(char *, char *, int);
extern int    RenameDirectory(BYTE, char *, char *);
extern int    RenameFile(char, char *, char, char, char *);
extern int    RestoreDirectoryHandle(char *, BYTE *, BYTE *);
extern int    RestoreErasedFile(BYTE, char *, char *, char *);
extern int    SaveDirectoryHandle(BYTE, char *);
extern int    ScanBinderyObject(char *, int, long *, char *, int *, char *, char *, char *);
extern int    ScanBinderyObjectTrusteePaths(long, BYTE, int *, char *, char *);
extern int    ScanDirectoryForTrustees(BYTE, char *, int *, char *, BYTE *, long *, long *, BYTE *);
extern int    ScanDirectoryInformation(BYTE, char *, int *, char *, BYTE *,	long *, BYTE *);
extern int    ScanFileInformation(BYTE, char *, BYTE, int *, char *, BYTE *, BYTE *, long *, char *, char *, char *, char *, long *);
extern int    ScanProperty(char *, int, char *, long *, char *, char *, char *, char *, char *);
extern int    SendBroadcastMessage(char *, WORD *, BYTE *, WORD);
extern int    SendConsoleBroadcast(char *, WORD, WORD *);
extern int    SendPersonalMessage(char *, WORD *, BYTE *, WORD);
extern void   SetBroadcastMode(BYTE);
extern void   SetDefaultLocalPrinter(BYTE);
extern int    SetDirectoryHandle(BYTE, char *, BYTE);
extern int    SetDirectoryInformation(BYTE, char *, BYTE *, long, BYTE);
extern int    SetDrivePath(BYTE, BYTE, char *, BYTE);
extern BYTE   SetEndOfJobStatus(BYTE);
extern int    SetExtendedFileAttributes(char *, BYTE);
extern int    SetFileInformation(BYTE, char *, BYTE, BYTE, BYTE, char *, char *, char *, char *, long);
extern int    SetFileServerDateAndTime(WORD, WORD, WORD, WORD, WORD, WORD);
extern void   SetLockMode(WORD);
extern void   SetNetWareErrorMode(WORD);
extern void   SetPreferredConnectionID(int);
extern void   SetPrimaryConnectionID(int);
extern void   SetPrimaryUserName(char *);
extern int    SetPrinterDefaults(int, int, int, int, int, char *, int, int, int);
extern void   SetSearchDriveVector(BYTE *);
extern int    SetSpoolFlags(char, int, int, int, int, char *);
extern int   _ShellRequest(BYTE, BYTE *, BYTE *);
extern int    SignalSemaphore(long);
extern int    SpecifyCaptureFile(BYTE, char *);
extern void   StartLSTCapture(void);
extern char  *StripFileServerFromPath(char *, char *);
extern int    TTSAbortTransaction(void);
extern int    TTSBeginTransaction(void);
extern int    TTSEndTransaction(long *);
extern int    TTSGetApplicationThresholds(BYTE *, BYTE *);
extern int    TTSGetWorkstationThresholds(BYTE *, BYTE *);
extern int    TTSIsAvailable(void);
extern int    TTSSetApplicationThresholds(BYTE, BYTE);
extern int    TTSSetWorkstationThresholds(BYTE, BYTE);
extern int    TTSTransactionStatus(long);
extern int    VerifyBinderyObjectPassword(char *, int, char *);
extern int    VerifyNetworkSerialNumber(long, int *);
extern int    WaitOnSemaphore(long, WORD);
extern void  _WriteEnvironment(char *);
extern int    WritePropertyValue(char *, int, char *, int, BYTE *, BYTE);
#else
extern int    AddBinderyObjectToSet();
extern int    AddTrusteeToDirectory();
extern int    AllocPermanentDirectoryHandle();
extern int    AllocTemporaryDirectoryHandle();
extern int    AppendToCaptureFile();
extern int    AttachToFileServer();
extern int    BroadcastToConsole();
extern int    CancelCaptureFile();
extern int    CancelLPTCapture();
extern int    ChangeBinderyObjectPassword();
extern int    ChangeBinderyObjectSecurity();
extern int    ChangePropertySecurity();
extern int    CheckConsolePrivileges();
extern int    CheckNetWareVersion();
extern int    CheckPipeStatus();
extern int    ClearConnectionNumber();
extern int    ClearFile();
extern void   ClearFileSet();
extern int    ClearLogicalRecord();
extern void   ClearLogicalRecordSet();
extern int    ClearPhysicalRecord();
extern void   ClearPhysicalRecordSet();
extern int    CloseBindery();
extern int    CloseMessagePipe();
extern int    CloseSemaphore();
extern int    ConvertNameToFullPath();
extern int    ConvertNameToVolumePath();
extern int    CreateBinderyObject();
extern int    CreateDirectory();
extern int    CreateProperty();
extern int    DeallocateDirectoryHandle();
extern int    DeleteBinderyObject();
extern int    DeleteBinderyObjectFromSet();
extern int    DeleteDirectory();
extern int    DeletePrintQueueEntries();
extern int    DeletePrintQueueEntry();
extern int    DeleteProperty();
extern int    DeleteTrusteeFromDirectory();
extern void   DetachFromFileServer();
extern int    DisableBroadcasts();
extern int    DisableFileServerLogin();
extern int    DisablePrinterDefaults();
extern int    DisableTransactionTracking();
extern int    DownFileServer();
extern int    EnableBroadcasts();
extern int    EnableFileServerLogin();
extern int    EnablePrinterDefaults();
extern int    EnableTransactionTracking();
extern void   EndLPTCapture();
extern void   EndOfJob();
extern int    EnterLoginArea();
extern int    EraseFiles();
extern int    ExamineSemaphore();
extern int    FileServerFileCopy();
extern int   _FileServiceRequest();
extern int    GetBinderyAccessLevel();
extern int    GetBinderyObjectID();
extern int    GetBinderyObjectName();
extern int    GetBroadcastMessage();
extern BYTE   GetBroadcastMode();
extern int    GetCaptureInfo();
extern int    GetConnectionHandle();
extern int    GetConnectionInformation();
extern WORD   GetConnectionNumber();
extern WORD   GetDefaultConnectionID();
extern BYTE   GetDefaultLocalPrinter();
extern int    GetDirectoryPath();
extern int    GetDiskUtilization();
extern BYTE   GetDriveInformation();
extern int    GetEffectiveDirectoryRights();
extern WORD  _GetEnvironmentSeg();
extern int    GetEnvironmentVariable();
extern int    GetExtendedFileAttributes();
extern void   GetFileServerDateAndTime();
extern int    GetFileServerDescriptionStrings();
extern int    GetFileServerExtendedInfo();
extern int    GetFileServerInformation();
extern int    GetFileServerLoginStatus();
extern void   GetFileServerName();
extern int    GetFullPath();
extern int    GetInternetAddress();
extern WORD   GetLockMode();
extern int    GetNetworkSerialNumber();
extern int    GetNumberOfLocalDrives();
extern int    GetObjectConnectionNumbers();
extern int    GetPersonalMessage();
extern int    GetPipeStatus();
extern WORD   GetPreferredConnectionID();
extern WORD   GetPrimaryConnectionID();
extern int    GetPrinterDefaults();
extern int    GetPrinterStatus();
extern int    GetPrintQueueEntry();
extern void   GetSearchDriveVector();
extern void   GetShellRevision();
extern void   GetStationAddress();
extern int    GetVolumeInfoWithHandle();
extern int    GetVolumeInfoWithNumber();
extern int    GetVolumeName();
extern int    GetVolumeNumber();
extern void  _GetWorkstationEnvironment();
extern void   GetWorkstationEnvironment();
extern int    IntSwap();
extern int    IsBinderyObjectInSet();
extern int    IsConnectionIDInUse();
extern int    LockFileSet();
extern int    LockLogicalRecordSet();
extern int    LockPhysicalRecordSet();
extern int    LogFile();
extern int    LoginToFileServer();
extern int    LoginUser();
extern int    LogLogicalRecord();
extern int    LogNetworkMessage();
extern void   Logout();
extern void   LogoutFromFileServer();
extern int    LogPhysicalRecord();
extern long   LongSwap();
extern int    LPTCaptureActive();
extern int   _MemberBinderyCall();
extern void   ModifyLSTDevice();
extern int    ModifyMaximumRightsMask();
extern int    OpenBindery();
extern int    OpenMessagePipe();
extern int    OpenSemaphore();
extern int    ParsePath();
extern int    PurgeAllErasedFiles();
extern int    PurgeErasedFiles();
extern int    PutEnvironmentVariable();
extern int    QueueCaptureFile();
extern int    QueueExistingFile();
extern BYTE *_ReadEnvironment();
extern int    ReadPropertyValue();
extern int    ReleaseFile();
extern void   ReleaseFileSet();
extern int    ReleaseLogicalRecord();
extern void   ReleaseLogicalRecordSet();
extern int    ReleasePhysicalRecord();
extern void   ReleasePhysicalRecordSet();
extern int    RenameBinderyObject();
extern int    RenameDirectory();
extern int    RenameFile();
extern int    RestoreDirectoryHandle();
extern int    RestoreErasedFile();
extern int    SaveDirectoryHandle();
extern int    ScanBinderyObject();
extern int    ScanBinderyObjectTrusteePaths();
extern int    ScanDirectoryForTrustees();
extern int    ScanDirectoryInformation();
extern int    ScanFileInformation();
extern int    ScanProperty();
extern int    SendBroadcastMessage();
extern int    SendConsoleBroadcast();
extern int    SendPersonalMessage();
extern void   SetBroadcastMode();
extern void   SetDefaultLocalPrinter();
extern int    SetDirectoryHandle();
extern int    SetDirectoryInformation();
extern int    SetDrivePath();
extern BYTE   SetEndOfJobStatus();
extern int    SetExtendedFileAttributes();
extern int    SetFileInformation();
extern int    SetFileServerDateAndTime();
extern void   SetLockMode();
extern void   SetNetWareErrorMode();
extern void   SetPreferredConnectionID();
extern void   SetPrimaryConnectionID();
extern void   SetPrimaryUserName();
extern int    SetPrinterDefaults();
extern void   SetSearchDriveVector();
extern int    SetSpoolFlags();
extern int   _ShellRequest();
extern int    SignalSemaphore();
extern int    SpecifyCaptureFile();
extern void   StartLSTCapture();
extern char  *StripFileServerFromPath();
extern int    TTSAbortTransaction();
extern int    TTSBeginTransaction();
extern int    TTSEndTransaction();
extern int    TTSGetApplicationThresholds();
extern int    TTSGetWorkstationThresholds();
extern int    TTSIsAvailable();
extern int    TTSSetApplicationThresholds();
extern int    TTSSetWorkstationThresholds();
extern int    TTSTransactionStatus();
extern int    VerifyBinderyObjectPassword();
extern int    VerifyNetworkSerialNumber();
extern int    WaitOnSemaphore();
extern void  _WriteEnvironment();
extern int    WritePropertyValue();
#endif
#else
extern BYTE   GetBroadcastMode();
extern WORD   GetConnectionNumber();
extern WORD   GetDefaultConnectionID();
extern BYTE   GetDefaultLocalPrinter();
extern BYTE   GetDriveInformation();
extern WORD  _GetEnvironmentSeg();
extern WORD   GetLockMode();
extern WORD   GetPreferredConnectionID();
extern WORD   GetPrimaryConnectionID();
extern long   LongSwap();
extern BYTE *_ReadEnvironment();
extern BYTE   SetEndOfJobStatus();
extern char  *StripFileServerFromPath();
#endif

